@@ -1,29 +1,21 @@
 #!/usr/bin/env python2.5 
-  # "Hildon Tutorial" version 2009-04-28
-   # Example 2.1, "Example of stackable windows"
    
 import gtk
 import hildon
 import sys
 import PrayerTime 
 import GPSPrayerLocator
+import thread
+import time
+import mythread
+import gobject
+import datetime
+import dbus
+
+gobject.threads_init()
 
 class prayertimeGTK:
-    def show_new_window(self,widget):
-         # Create the main window
-         win = hildon.StackableWindow()
-         win.set_title("Subview")
-     
-         # Setting a label in the new window
-         label = gtk.Label("This is a subview")
-     
-         vbox = gtk.VBox(False, 0)
-         vbox.pack_start(label, True, True, 0)
-     
-         win.add(vbox)
-     
-         # This call show the window and also add the window to the stack
-         win.show_all()
+
     def main(self):
          self.tz = "0"
          self.lng = "0"
@@ -62,19 +54,31 @@ class prayertimeGTK:
          elif(self.mode == "MAN"):
             times = self.prayerTime.calculate(int(self.tz),float(self.lat),float(self.lng))
          self.vbox = gtk.VBox()
+         self.times = times
          header = gtk.Label("PrayerTimes")
          self.vbox.pack_start(header)
          self.prayerTab = self.create_layout_tab(times,self.names)
          self.vbox.pack_start(self.prayerTab)
          #self.pan.add_with_viewport(self.vbox)
          win.add(self.vbox)
-         
+                  
      
          win.connect("destroy", gtk.main_quit, None)
-     
          # This call show the window and also add the window to the stack
          win.show_all()
          gtk.main()
+         print 'out main'
+         
+    def getNextPrayer(self):
+      for i in xrange(len(self.times)):
+        if self.times[i] >= datetime.datetime.now().time():
+          return i
+      print self.times[0]
+      print datetime.datetime.now().time()
+      print 'No Next'
+      return 0
+    
+
     def formatTime(self,time):
         return self.twoDigitsFormat(time.hour)+':'+ self.twoDigitsFormat(time.minute);
         
@@ -82,6 +86,7 @@ class prayertimeGTK:
             if(num < 10):
                 return "0" + str(int(num))
             return str(int(num))
+
     def create_layout_tab(self,times,names):
         table = gtk.Table(2,3)
         j = 0 
@@ -93,14 +98,10 @@ class prayertimeGTK:
         return table
      
     def create_menu(self):
-        menu = hildon.AppMenu()
-    
-        
+        menu = hildon.AppMenu()        
         button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
         command_id = "Location Settings"
         button.set_label(command_id)
-        
-            # Attach callback to clicked signal
         button.connect("clicked", self.show_settings_window)
         menu.append(button)
         
@@ -112,10 +113,39 @@ class prayertimeGTK:
         
         menu.append(button)
         
+        
+        button = hildon.GtkButton(gtk.HILDON_SIZE_AUTO)
+        command_id = "Hide"
+        button.set_label(command_id)
+        button.connect("clicked", self.hideTest)
+        menu.append(button)
+        
         menu.show_all()
         
         return menu
     
+    def hideTest(self,widget):
+          if hasattr(self,'tt'):
+               self.tt = None
+          self.nextPrayerIndex = self.getNextPrayer()
+          print self.nextPrayerIndex
+          if self.nextPrayerIndex == None:
+               secondsTillTomorrow = 24*3600 - toSeconds(datetime.datetime.now().time())
+               sleeptime = toSeconds(self.times[0])+secondsTillTomorrow
+               self.nextPrayerIndex = 0
+          else:
+               sleeptime = diffTime(self.times[self.nextPrayerIndex],datetime.datetime.now().time())
+          print sleeptime
+          self.tt = mythread.notifier(self,sleeptime)
+          self.tt.start()
+          self.tt=None
+          self.gtkwin.hide()
+          print 'thread should be running'
+        
+    def showTest(self):
+        self.gtkwin.show_all()
+        banner = hildon.hildon_banner_show_information(self.gtkwin, " ", "It is Time for: "+self.names[self.nextPrayerIndex])
+
     def show_settings_window(self,widget):
            # Create the main window
            win = hildon.StackableWindow()
@@ -271,9 +301,22 @@ class prayertimeGTK:
         banner = hildon.hildon_banner_show_information(self.gtkwin, " ", "done getting prayer for "+str(self.lat)+":"+str(self.lng))
    
 
-        
-        
+def diffTime(time1,time2):
+	ss = 0
+	ss = time1.hour*3600 - time2.hour*3600
+	ss +=  (time1.minute-time2.minute)*60
+	ss = ss + time1.second - time2.second
+	return ss
+def toSeconds(time1):
+     ss = ime1.hour*3600+time1.minute*60+time1.second
+     return ss
+
+def showTest():
+  while 1:
+        print 'in thread'
+        time.sleep(2)
+        print 'out thread'
 
 if __name__ == "__main__":
      ui = prayertimeGTK()
-     ui.main()
\ No newline at end of file
+     ui.main()
